# Models

This repository contains demo models for the Teradata AOA. See the [HowTo](./HOWTO.md) guide for a brief tutorial on how to add new models.

# Available Models

More human friendly folder names for each model under model_definitions is tracked in [issue-105](https://github.com/ThinkBigAnalytics/AoaCoreService/issues/105).


# Adding new Models

Use the aoa cli (see [here](https://pypi.org/project/aoa/))

    aoa add

## Running Models Locally

Use the aoa cli (see [here](https://pypi.org/project/aoa/))

    aoa run -h
    
## Detailed Documentation

To see more detailed documentation on supported model signatures, additional variables passed to the models, how we store and retrieve artifacts and metrics, see the following [document](https://github.com/ThinkBigAnalytics/AoaCoreService/blob/master/docs/ModelsSupport.md).